pub struct TmaiCoreBuilder { /* private fields */ }Expand description
Builder for constructing a TmaiCore Facade instance
Implementations
Sourceimpl TmaiCoreBuilder
impl TmaiCoreBuilder
Create a new builder from an already-shared settings
Sourcepub fn with_state(self, state: SharedState) -> Self
pub fn with_state(self, state: SharedState) -> Self
Use an existing shared state instead of creating a new one
Sourcepub fn with_ipc_server(self, ipc_server: Arc<IpcServer>) -> Self
pub fn with_ipc_server(self, ipc_server: Arc<IpcServer>) -> Self
Set the IPC server for PTY wrapper communication
Sourcepub fn with_command_sender(self, sender: Arc<CommandSender>) -> Self
pub fn with_command_sender(self, sender: Arc<CommandSender>) -> Self
Set the command sender
Sourcepub fn with_audit_sender(self, tx: AuditEventSender) -> Self
pub fn with_audit_sender(self, tx: AuditEventSender) -> Self
Set the audit event sender for emitting audit events