pub struct ClaudeSettingsCache { /* private fields */ }Expand description
Cache for Claude Code settings per project path
Settings are cached permanently since Claude Code requires a session restart to pick up setting changes.
Implementations
Sourceimpl ClaudeSettingsCache
impl ClaudeSettingsCache
Sourcepub fn get_settings(&self, cwd: Option<&str>) -> Option<ClaudeSettings>
pub fn get_settings(&self, cwd: Option<&str>) -> Option<ClaudeSettings>
Get merged settings for a project path (cwd)
Returns None if cwd is None or settings cannot be read. Merges settings in priority order. Settings are cached permanently per project path.