Module server

Module server 

IPC server for tmai parent process

Listens on a Unix domain socket for wrapper connections and maintains a registry of connected wrapper states.

Structs

IpcServer
IPC server that manages wrapper connections

Type Aliases

IpcRegistry
Registry of connected wrapper states, keyed by pane_id