pub struct Analyzer { /* private fields */ }Expand description
Analyzer for PTY output
Implementations
Sourceimpl Analyzer
impl Analyzer
Sourcepub fn team_member_name(&self) -> Option<&String>
pub fn team_member_name(&self) -> Option<&String>
Get team member name
Sourcepub fn is_team_lead(&self) -> bool
pub fn is_team_lead(&self) -> bool
Whether this agent is the team lead
Sourcepub fn process_output(&mut self, data: &str)
pub fn process_output(&mut self, data: &str)
Process output data
Sourcepub fn process_input(&mut self, _data: &str)
pub fn process_input(&mut self, _data: &str)
Process input data
Clears pending approval and output buffer to prevent re-triggering approval detection from stale output after user input.
Sourcepub fn clear_buffer(&mut self)
pub fn clear_buffer(&mut self)
Clear the output buffer